package market.Mes.Cuttolength.Plan.mapper;
import java.util.HashMap;
import java.util.List;

import market.Mes.Cuttolength.Plan.vo.CommentDetialAndCuttD;
import market.Mes.Cuttolength.Plan.vo.PlnCuttolengthPlanDetail;

import org.apache.ibatis.annotations.Update;

import com.hnshituo.orm.GenericMapper;

public interface PlnCuttolengthPlanDetailMapper extends GenericMapper<PlnCuttolengthPlanDetail,Object> {

	
	
	List<HashMap> doQueryWorkPlanWeb(String code);
	/**
	 * 动作处理-自动定位按钮-当班汇总信息
	 * 前端将页面全局变量V_MCH_CODE（机台代码）、V_WRK_DATE（登录日期）、V_WRK_ORD（登录班次）、V_WRK_GRP（登录班组）传入后台；
	 * @param code
	 * @param date
	 * @param ord
	 * @param grp
	 * @return
	 */
	List<HashMap> doQueryWrkSumInfoWeb(String code,String date ,String ord,String grp);

	List<HashMap> doQueryWorkPlanWeb3_bak(String memo1, String sWhere);
	
	List<HashMap> doQueryWorkPlanWeb3(String memo1, String startTime, String endTime,
			String memo2, String memo3);
	
	
	List<HashMap> doQueryWorkPlanWeb4(String v_object_no_vt);
	
	List<HashMap> doQueryWorkPlanWeb5(String v_plan_no,String v_object_no_vt);
	
	List<HashMap> doQueryWorkPlanWeb6(String v_plan_no,String v_object_no_vt);
	
	// 删除分条计划明细相关母卷数据
	void doDelete(PlnCuttolengthPlanDetail p);

	//修改开平计划明细表：计划内的的各母卷分别修改状态为：5BCL02	
	void doUpdateStatus(PlnCuttolengthPlanDetail pcc);
	
	
	//将板垛实绩，与板垛计划，按顺序逐一比较，厚宽长，如果全在运行偏差范围，则挂单，否则脱单
	List<CommentDetialAndCuttD> doQueryDetail(String process_no,String V_OBJECT_NO_VT);
	List<HashMap> doQueryWorkPlanWeb6_wgt(String v_plan_no, String v_object_no_vt);
	
	
	@Update("update PLN_CUTTOLENGTH_PLAN_DETAIL set status =  #{status} where object_no_vt = #{object_no_vt} and cl_plan_no = #{cl_plan_no}")
	void doUpdateWSum(PlnCuttolengthPlanDetail plpd);
	
	@Update("update PLN_CUTTOLENGTH_PLAN_DETAIL set status =  #{status} where object_no = #{object_no} and cl_plan_no = #{cl_plan_no}")
	void doUpdatee(PlnCuttolengthPlanDetail pcpdxxx);
	
}
