/***文档注释***********************************************
 * 作者            ：
 * 创建日期     ：2018-05-31
 * 描述            ：横剪计划明细表
 * 注意事项     ：
 * 遗留BUG   ：
 * 修改日期     ：
 * 修改人员     ：
 * 修改内容     ：
***********************************************************/
package market.Mes.Cuttolength.Plan.impl;
import market.Com.vo.CommonPage;
import market.Com.vo.ResultModel;
import market.Mes.Cuttolength.Plan.mapper.PlnCuttolengthPlanDetailMapper;
import market.Mes.Cuttolength.Plan.service.PlnCuttolengthPlanDetailService;
import market.Mes.Cuttolength.Plan.vo.PlnCuttolengthPlanDetail;

import com.hnshituo.basic.service.impl.BaseServiceImpl;
import com.hnshituo.basic.spring.remoting.annotation.RemoteService;

@RemoteService(path="PlnCuttolengthPlanDetailService")
public class PlnCuttolengthPlanDetailServiceImpl extends BaseServiceImpl<PlnCuttolengthPlanDetail,Object> implements PlnCuttolengthPlanDetailService {
	
	
	/**
	 * 查询开平作业计划
	 * @param V_MCH_CODE（机台代码）
	 * @return
	 */
	public ResultModel doQueryWeb(String code){
		ResultModel rm=new ResultModel(); 
		try{
			rm.setData(this.getBean(PlnCuttolengthPlanDetailMapper.class).doQueryWorkPlanWeb(code));
			rm.setState("200");
		}catch(Exception ex){
			rm.setState("500");
			rm.setMsgInfo("查询失败！");
			ex.printStackTrace();
			rm.setErrorInfo(ex.getMessage());
		}
		return rm;
	}
	
	/**
	 * 查询当班汇总信息
	 * V_MCH_CODE（机台代码）、V_WRK_DATE（登录日期）、V_WRK_ORD（登录班次）、V_WRK_GRP（登录班组）
	 * @param code
	 * @param v_wrk_date
	 * @param v_wrk_ord
	 * @param v_wrk_grp
	 * @return
	 */
	public ResultModel doQueryWrkSumInfoWeb(String c_mch_code,String v_wrk_date,String v_wrk_ord,String v_wrk_grp){
		ResultModel rm=new ResultModel(); 
		try{
			if(c_mch_code==null || "".equals(c_mch_code)){
				rm.setState("500");
				rm.setMsgInfo("机台代码为空！");
				return rm;
			}
			if(v_wrk_date==null || "".equals(v_wrk_date)){
				rm.setState("500");
				rm.setMsgInfo("登录日期为空！");
				return rm;
			}
			if(v_wrk_ord==null || "".equals(v_wrk_ord)){
				rm.setState("500");
				rm.setMsgInfo("登录班次为空！");
				return rm;
			}
			if(v_wrk_grp==null || "".equals(v_wrk_grp)){
				rm.setState("500");
				rm.setMsgInfo("登录班组为空！");
				return rm;
			}
			rm.setData(this.getBean(PlnCuttolengthPlanDetailMapper.class).doQueryWrkSumInfoWeb(c_mch_code, v_wrk_date, v_wrk_ord, v_wrk_grp));
			rm.setState("200");
		}catch(Exception ex){
			rm.setState("500");
			rm.setMsgInfo("查询失败！");
			ex.printStackTrace();
			rm.setErrorInfo(ex.getMessage());
		}
		return rm;
	}
	
	/**动作处理-查询
	  memo1:机台代码
	  memo2：作业计划号
	  memo3:原料卷号
	  startTime
	  endTime
	 * @return
	 */
	public ResultModel doQueryWeb3(CommonPage<PlnCuttolengthPlanDetail> cp){
		ResultModel rm=new ResultModel(); 
		try{
			if(cp.getMemo1()==null || "".equals(cp.getMemo1())){
				rm.setState("500");
				rm.setMsgInfo("机台代码为空！");
				return rm;
			}
			rm.setData(this.getBean(PlnCuttolengthPlanDetailMapper.class).doQueryWorkPlanWeb3(cp.getMemo1(),cp.getStartTime(),cp.getEndTime(),cp.getMemo2(),cp.getMemo3()));
			rm.setState("200");
		}catch(Exception ex){
			rm.setState("500");
			rm.setMsgInfo("查询失败！");
			ex.printStackTrace();
			rm.setErrorInfo(ex.getMessage());
		}
		return rm;
	}
	
	/**
	 *板垛计划（表格数据）处理：- 开平计划
	 * @param V_OBJECT_NO_VT
	 * @return
	 */
	public ResultModel doQueryWeb4(String v_object_no_vt){
		ResultModel rm=new ResultModel(); 
		try{
			rm.setData(this.getBean(PlnCuttolengthPlanDetailMapper.class).doQueryWorkPlanWeb4(v_object_no_vt));
			rm.setState("200");
		}catch(Exception ex){
			rm.setState("500");
			rm.setMsgInfo("查询失败！");
			ex.printStackTrace();
			rm.setErrorInfo(ex.getMessage());
		}
		return rm;
	}
	
	/**
	 *生产主实绩”（编辑区域一）处理：开平计划
	 * @param v_plan_no 作业计划号
	 * @param v_object_no_vt 虚拟母卷号
	 * @return
	 */
	public ResultModel doQueryWeb5(String v_plan_no,String v_object_no_vt){
		ResultModel rm=new ResultModel(); 
		try{
			rm.setData(this.getBean(PlnCuttolengthPlanDetailMapper.class).doQueryWorkPlanWeb5(v_plan_no, v_object_no_vt));
			rm.setState("200");
		}catch(Exception ex){
			rm.setState("500");
			rm.setMsgInfo("查询失败！");
			ex.printStackTrace();
			rm.setErrorInfo(ex.getMessage());
		}
		return rm;
	}
	/**
	 * 板垛实绩”（表格数据）处理：-开平计划
	 * @param v_plan_no
	 * @param v_object_no_vt
	 * @return
	 */
	public ResultModel doQueryWeb6(String v_plan_no,String v_object_no_vt){
		ResultModel rm=new ResultModel(); 
		try{
			rm.setData(this.getBean(PlnCuttolengthPlanDetailMapper.class).doQueryWorkPlanWeb6(v_plan_no, v_object_no_vt));
			rm.setState("200");
		}catch(Exception ex){
			rm.setState("500");
			rm.setMsgInfo("查询失败！");
			ex.printStackTrace();
			rm.setErrorInfo(ex.getMessage());
		}
		return rm;
	}
	
	/**
	 * 板垛实绩”（表格数据）处理：-开平计划  ---称重页面
	 * @param v_plan_no
	 * @param v_object_no_vt
	 * @return
	 */
	public ResultModel doQueryWeb6_wgt(String v_plan_no,String v_object_no_vt){
		ResultModel rm=new ResultModel(); 
		try{
			rm.setData(this.getBean(PlnCuttolengthPlanDetailMapper.class).doQueryWorkPlanWeb6_wgt(v_plan_no, v_object_no_vt));
			rm.setState("200");
		}catch(Exception ex){
			rm.setState("500");
			rm.setMsgInfo("查询失败！");
			ex.printStackTrace();
			rm.setErrorInfo(ex.getMessage());
		}
		return rm;
	}
	
	
}
